@@ -14,7 +14,7 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-import json
+import yajl as json
 from django.conf import settings
 from django.contrib.auth import authenticate, login
 from django.views.decorators.csrf import csrf_exempt
@@ -126,7 +126,11 @@ class APIView(View):
             'http_status_code': error_obj.status_code,
             'error': error_obj.message,
         }
-        try: result['meta'] = json.loads(json.dumps(error_obj.init_kwargs))
+        meta = {}
+        if len(error_obj.user_info.items()): meta['user_info'] = error_obj.user_info
+        if len(error_obj.init_kwargs.items()): meta['keyword'] = error_obj.init_kwargs
+
+        try: result['meta'] = json.loads(json.dumps(meta))
         except TypeError: pass
         self.response.content = json.dumps(result)
 
