@@ -26,11 +26,15 @@ from eggplant.views import View
 
 def _get_request_data(request):
     if request.method.lower() == 'put':
-        if DJANGO_VERSION[1] >= 4:
-            raw_request_data = request.body
+        if hasattr(request, request.method.upper()):
+            request_data = request.PUT
         else:
-            raw_request_data = request.raw_post_data
-        request_data = QueryDict(raw_request_data)
+            if DJANGO_VERSION[1] >= 4:
+                raw_request_data = request.body
+            else:
+                raw_request_data = request.raw_post_data
+            request_data = QueryDict(raw_request_data)
+            setattr(request, request.method.upper(), request_data)
     elif request.method.lower() == 'post':
         request_data = request.POST
     else:
@@ -58,6 +62,29 @@ def _get_wrapped_type(args):
     return view_object, request, is_class_based
 
 
+def _normalize_key_validator_pairs(raw_pairs):
+    key_validator_pairs = list(raw_pairs)
+    if len(raw_pairs)==2:
+        if isinstance(raw_pairs[0], six.string_types):
+            key_validator_pairs[0] = [raw_pairs[0]]
+        if isinstance(raw_pairs[1], (types.FunctionType, staticmethod)):
+            key_validator_pairs[1] = [raw_pairs[1]]
+
+        is_key_list = True
+        for item in key_validator_pairs[0]:
+            if not isinstance(item, six.string_types):
+                is_key_list = False
+                break
+        is_validator_list = True
+        for item in key_validator_pairs[1]:
+            if not isinstance(item, (types.FunctionType, staticmethod)):
+                is_validator_list = False
+                break
+        if is_key_list and is_validator_list:
+            key_validator_pairs = (key_validator_pairs,)
+    return key_validator_pairs
+
+
 def required_keys(*keys, **kwargs):
     error_handler = kwargs.get('error_handler', None)
     if error_handler is None:
@@ -89,7 +116,7 @@ def required_keys(*keys, **kwargs):
     return wrapper
 
 
-def validate_keys(*raw_key_validator_pairs, **kwargs):
+def validate_keys(*raw_key_validator_tuple, **kwargs):
     error_handler = kwargs.get('error_handler', None)
     if error_handler is None:
         error_handler = key_validation_failed_default_handler
@@ -103,21 +130,7 @@ def validate_keys(*raw_key_validator_pairs, **kwargs):
 
             request_data = _get_request_data(request)
 
-            # Check what's input
-            key_validator_pairs = raw_key_validator_pairs
-            if len(raw_key_validator_pairs)==2:
-                is_key_list = True
-                for item in raw_key_validator_pairs[0]:
-                    if not isinstance(item, six.string_types):
-                        is_key_list = False
-                        break
-                is_validator_list = True
-                for item in raw_key_validator_pairs[1]:
-                    if not isinstance(item, (types.FunctionType, staticmethod)):
-                        is_validator_list = False
-                        break
-                if is_key_list and is_validator_list:
-                    key_validator_pairs = (raw_key_validator_pairs,)
+            key_validator_pairs = _normalize_key_validator_pairs(raw_key_validator_tuple)
 
             for request_key, validator in key_validator_pairs:
                 if not isinstance(request_key, (list, tuple)): keys = [request_key]
